﻿using System;
using System.Windows.Forms;

using Infragistics.Win.UltraWinEditors;

namespace Ping.Controls
{
	public class DnmNumericEditor : UltraNumericEditor
	{
		#region -- Private data ----------------------------------------------
		private double oldValue = 0;
		#endregion -----------------------------------------------------------

		#region -- Overridden methods ----------------------------------------

		protected override void OnValueChanged (EventArgs args)
		{
		}

		// -------------------------------------------------------------------

		protected override void OnEditorSpinButtonClick (SpinButtonClickEventArgs e)
		{
			double newVal = toDouble (Value);
			if (e.ButtonType == Infragistics.Win.UltraWinEditors.SpinButtonItem.NextItem)
			{
				newVal += toDouble (SpinIncrement);
			}
			else if (e.ButtonType == Infragistics.Win.UltraWinEditors.SpinButtonItem.PreviousItem)
			{
				newVal -= toDouble (SpinIncrement);
			}

			double min = toDouble (MinValue);
			double max = toDouble (MaxValue);
			if (newVal < min)
				newVal = min;
			else if (newVal > max)
				newVal = max;

			Value = newVal;

			valueChanged ();

			base.OnEditorSpinButtonClick (e);
		}

		// -------------------------------------------------------------------

		protected override void OnBeforeExitEditMode (Infragistics.Win.BeforeExitEditModeEventArgs args)
		{
			valueChanged ();
			base.OnBeforeExitEditMode (args);
		}

		// -------------------------------------------------------------------

		protected override void OnKeyPress (System.Windows.Forms.KeyPressEventArgs e)
		{
			if (e.KeyChar == '\r')
				valueChanged ();

			base.OnKeyPress (e);
		}

		// -------------------------------------------------------------------

		protected override void OnKeyUp (System.Windows.Forms.KeyEventArgs e)
		{
			if (e.Shift || e.Control || e.Alt)
				return;

			if ((e.KeyCode == Keys.Up) ||
				(e.KeyCode == Keys.Down))
			{
				valueChanged ();
			}

			base.OnKeyUp (e);
		}

		#endregion -----------------------------------------------------------

		#region -- Private methods -------------------------------------------

		private void valueChanged ()
		{
			double newVal = Convert.ToDouble (Text.TrimStart (PromptChar));
			if (oldValue != newVal)
				base.OnValueChanged (new EventArgs ());

			oldValue = newVal;
		}

		// -------------------------------------------------------------------

		private double toDouble (object o)
		{
			Type type = o.GetType ();
			if (type.Equals (typeof (int)))
				return (double)((int)o);
			else if (type.Equals (typeof (double)))
				return (double)o;
			else if (type.Equals (typeof (float)))
				return (double)((float)o);

			throw new Exception (string.Format ("Cannot convert {0} to double", o.GetType ().ToString ()));
		}

		#endregion -----------------------------------------------------------
	}
}
