﻿using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;

using Infragistics.Win.UltraWinGrid;
using Infragistics.Win.UltraWinEditors;

using Ping.Controls;

namespace GridNumEdit
{
	public partial class Form1 : Form
	{
		public Form1 ()
		{
			InitializeComponent ();

			DataTable dt = new DataTable ("tblEqualizer");

			DataColumn dcSectNr	= new DataColumn ("colSectNr",	typeof (int));
			dcSectNr.Caption = "Nr";
			dcSectNr.ReadOnly = true;
			dt.Columns.Add (dcSectNr);

			DataColumn dcFreq	= new DataColumn ("colFreq",	typeof (int));
			dcFreq.Caption = "Freq.";
			dt.Columns.Add (dcFreq);

			DataColumn dcGain	= new DataColumn ("colGain",	typeof (double));
			dcGain.Caption = "Gain";
			dt.Columns.Add (dcGain);

			DataColumn dcQfact	= new DataColumn ("colQfact",	typeof (double));
			dcQfact.Caption = "Q-factor";
			dt.Columns.Add (dcQfact);

			grd.DataSource = dt;
		}

		// -------------------------------------------------------------------

		private void grd_InitializeLayout (object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
		{
			ColumnsCollection cc = e.Layout.Bands[0].Columns;

			cc["colSectNr"].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
			cc["colFreq"  ].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
			cc["colGain"  ].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
			cc["colQfact" ].MaskInput = "{double:2.3}";
			cc["colQfact" ].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
		}

		// -------------------------------------------------------------------

		private void grd_InitializeRow (object sender, InitializeRowEventArgs e)
		{
			if (e.Row.Cells["colFreq"].EditorComponent == null)
			{
				DnmNumericEditor ed = new DnmNumericEditor ();
				ed.NumericType = NumericType.Double;
				ed.MinValue  =     20;
				ed.MaxValue  =  20000;
				ed.MaskInput = "nnnnn";
				ed.SpinIncrement = 10.0;
				ed.Tag = e.Row;
//				ed.ValueChanged += new EventHandler (ed_ValueChanged);

				e.Row.Cells["colFreq"].EditorComponent = ed;
				e.Row.Cells["colFreq"].EditorResolved.ValueChanged	+= new EventHandler			(ed_ValueChanged);
				e.Row.Cells["colFreq"].EditorResolved.KeyPress		+= new KeyPressEventHandler	(EditorResolved_KeyPress);
				e.Row.Cells["colFreq"].EditorResolved.KeyUp			+= new KeyEventHandler		(EditorResolved_KeyUp);
			}

			if (e.Row.Cells["colGain"].EditorComponent == null)
			{
				UltraNumericEditor ed = new UltraNumericEditor ();
				ed.NumericType = NumericType.Double;
				ed.MinValue = -12.0;
				ed.MaxValue =  12.0;
				ed.MaskInput = "-nn.n";

				e.Row.Cells["colGain"].EditorComponent = ed;
			}

			if (e.Row.Cells["colQfact"].EditorComponent == null)
			{
				UltraNumericEditor ed = new UltraNumericEditor ();
				ed.NumericType = NumericType.Double;
				ed.MinValue = 0.1;
				ed.MaxValue = 9.0;
				ed.MaskInput = "{double:2.1}";
				e.Row.Cells["colQfact"].EditorComponent = ed;
			}
		}

		// -------------------------------------------------------------------

		void EditorResolved_KeyUp (object sender, KeyEventArgs e)
		{
			Console.WriteLine ("EditorResolved_KeyUp :{0}", sender);
		}

		// -------------------------------------------------------------------

		void EditorResolved_KeyPress (object sender, KeyPressEventArgs e)
		{
			Console.WriteLine ("EditorResolved_KeyPress :{0}", sender);
		}

		// -------------------------------------------------------------------

		void ed_ValueChanged (object sender, EventArgs e)
		{
			Console.WriteLine ("ed_ValueChanged :{0}", sender);
		}

		// -------------------------------------------------------------------

		private void dataToEqualizerGrid ()
		{
			DataTable dt = (DataTable)grd.DataSource;
			dt.Rows.Clear ();

			for (int ind = 0; ind < 10; ind++)
			{
				DataRow row = dt.NewRow ();

				row["colSectNr"] =	ind + 1;
				row["colFreq"  ] =	1000;
				row["colGain"  ] =	0.0;
				row["colQfact" ] =	0.707;

				dt.Rows.Add (row);
			}
		}

		// -------------------------------------------------------------------

		private void Form1_Load (object sender, EventArgs e)
		{
			dataToEqualizerGrid ();
		}

		// -------------------------------------------------------------------

		private void grd_CellChange (object sender, CellEventArgs e)
		{
			Console.WriteLine ("grd_CellChange :({0}, {1})", e.Cell.Row.Index, e.Cell.Column.Index);
		}

		// -------------------------------------------------------------------

		private void grd_AfterCellUpdate (object sender, CellEventArgs e)
		{
			Console.WriteLine ("grd_AfterCellUpdate :({0}, {1})", e.Cell.Row.Index, e.Cell.Column.Index);
		}

		// -------------------------------------------------------------------

		private void ned_ValueChanged (object sender, EventArgs e)
		{
			Console.WriteLine ("ned_ValueChanged :{0}", ned.Value);
		}
	}
}
